]> git.sesse.net Git - stockfish/commitdiff
ValueType needs only 2 bits to be stored in TT
authorJoona Kiiski <joona.kiiski@gmail.com>
Thu, 22 Jul 2010 13:11:08 +0000 (16:11 +0300)
committerMarco Costalba <mcostalba@gmail.com>
Thu, 22 Jul 2010 16:51:33 +0000 (17:51 +0100)
Also update some more TT documentation

No functional change

Signed-off-by: Marco Costalba <mcostalba@gmail.com>
src/tt.h

index f096c55228b1caeb1e1f02b8f01aadf061f7fa3d..0b95ea635997d87f7b999917951f24d2be90ad21 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -48,8 +48,8 @@
 /// the 32 bits of the data field are so defined
 ///
 /// bit  0-16: move
 /// the 32 bits of the data field are so defined
 ///
 /// bit  0-16: move
/// bit 17-19: not used
/// bit 20-22: value type
 /// bit 23-31: generation
 
 class TTEntry {
 /// bit 23-31: generation
 
 class TTEntry {
@@ -58,7 +58,7 @@ public:
   void save(uint32_t k, Value v, ValueType t, Depth d, Move m, int g, Value statV, Value kd) {
 
       key32 = k;
   void save(uint32_t k, Value v, ValueType t, Depth d, Move m, int g, Value statV, Value kd) {
 
       key32 = k;
-      data = (m & 0x1FFFF) | (t << 20) | (g << 23);
+      data = (m & 0x1FFFF) | (t << 21) | (g << 23);
       value16     = int16_t(v);
       depth16     = int16_t(d);
       staticValue = int16_t(statV);
       value16     = int16_t(v);
       depth16     = int16_t(d);
       staticValue = int16_t(statV);
@@ -69,7 +69,7 @@ public:
   Depth depth() const { return Depth(depth16); }
   Move move() const { return Move(data & 0x1FFFF); }
   Value value() const { return Value(value16); }
   Depth depth() const { return Depth(depth16); }
   Move move() const { return Move(data & 0x1FFFF); }
   Value value() const { return Value(value16); }
-  ValueType type() const { return ValueType((data >> 20) & 7); }
+  ValueType type() const { return ValueType((data >> 21) & 3); }
   int generation() const { return data >> 23; }
   Value static_value() const { return Value(staticValue); }
   Value king_danger() const { return Value(kingDanger); }
   int generation() const { return data >> 23; }
   Value static_value() const { return Value(staticValue); }
   Value king_danger() const { return Value(kingDanger); }
@@ -84,13 +84,12 @@ private:
 };
 
 
 };
 
 
-/// This is the number of TTEntry slots for each position
+/// This is the number of TTEntry slots for each cluster
 const int ClusterSize = 4;
 
 const int ClusterSize = 4;
 
-/// Each group of ClusterSize number of TTEntry form a TTCluster
-/// that is indexed by a single position key. TTCluster size must
-///  be not bigger then a cache line size, in case it is less then
-/// it should be padded to guarantee always aligned accesses.
+/// TTCluster consists of ClusterSize number of TTEntries.
+/// Size of TTCluster must not be bigger than a cache line size.
+/// In case it is less, it should be padded to guarantee always aligned accesses.
 
 struct TTCluster {
   TTEntry data[ClusterSize];
 
 struct TTCluster {
   TTEntry data[ClusterSize];
@@ -98,7 +97,7 @@ struct TTCluster {
 
 
 /// The transposition table class. This is basically just a huge array
 
 
 /// The transposition table class. This is basically just a huge array
-/// containing TTEntry objects, and a few methods for writing new entries
+/// containing TTCluster objects, and a few methods for writing new entries
 /// and reading new ones.
 
 class TranspositionTable {
 /// and reading new ones.
 
 class TranspositionTable {
@@ -123,8 +122,8 @@ extern TranspositionTable TT;
 
 
 /// TranspositionTable::first_entry returns a pointer to the first
 
 
 /// TranspositionTable::first_entry returns a pointer to the first
-/// entry of a cluster given a position. The low 32 bits of the key
-/// are used to get the index in the table.
+/// entry of a cluster given a position. The lowest order bits of the key
+/// are used to get the index of the cluster.
 
 inline TTEntry* TranspositionTable::first_entry(const Key posKey) const {
 
@@ -48,8 +48,8 @@
 ///
 /// bit  0-16: move
-/// bit 17-19: not used
-/// bit 20-22: value type
+/// bit 17-20: not used
+/// bit 21-22: value type
 /// bit 23-31: generation
 
 
 inline TTEntry* TranspositionTable::first_entry(const Key posKey) const {